#!/usr/bin/python

# Configuration information for testcode.py.  Written for the CPMD/NECI 
# codebase.  This should be trivial to adapt for other situations.

# Import user information.
from userconfig import *

# Each job is described by a python dict.  Sets of jobs are described by 
# python lists.  Lists can be concatenated (+ operator).  Repetitions are
# tested for.

# Describe jobs.

GCPMD_Graphite = {
'dir': 'GCPMD_Graphite',
'type': cpmd
}
GCPMD_HHx4 = {
'dir':'GCPMD_HHx4',
'type': cpmd
}
GCPMD_H2 = {
'dir': 'GCPMD_H2',
'type': cpmd
}

KCPMD_H2 = {
'dir': 'KCPMD_H2',
'type': cpmd
}
KCPMD_HHx4 = {
'dir': 'KCPMD_HHx4',
'type': cpmd
}
KCPMD_LiH = {
'dir': 'KCPMD_LiH',
'type': cpmd,
'cpmd.inp Sum tolerance':2.e-10,
}
KCPMDlong_Diamond = {
'dir': 'KCPMDlong_Diamond',
'type': cpmd
}
KCPMDlong_Si = {
'dir': 'KCPMDlong_Si',
'type': cpmd
}

NECI_O3 = {
'dir': 'NECI_O3',
'type':neci
}
NECI_H2 = {
'dir': 'NECI_H2',
'type':neci,
'neci.inp Sum tolerance':3.5e-9,
}
NECIlong_MC_O3 = {
'dir': 'NECIlong_MC_O3',
'type':neci,
'neci.inp Sum tolerance':7.e-10,
}
NECI_NN_STARDF_32BIT = {
'dir': 'NECI_NN_STARDF_32BIT',
'type':neci
}
NECIlong_Ne = {
'dir': 'NECIlong_Ne',
'type':neci,
'neci.inp Sum tolerance':1.05e-7
}
NECI_MC_H2O = {
'dir': 'NECI_MC_H2O',
'type':neci,
'neci.inp Sum tolerance':4.e-7
}
NECI_B_UHF = {
'dir': 'NECI_B_UHF',
'type':neci
}
NECI_HUB2x2n4 = {
'dir': 'NECI_HUB2x2n4',
'type':neci
}
NECI_HUB2x2tn4 = {
'dir': 'NECI_HUB2x2tn4',
'type':neci
}
NECI_BOX_2eR10diag = {
'dir':'NECI_BOX_2eR10diag',
'type':neci
}
# Form job categories.

GCPMD = [
GCPMD_Graphite,
GCPMD_H2,
GCPMD_HHx4
]

KCPMD = [
KCPMD_H2,
KCPMD_HHx4,
KCPMD_LiH
]

CPMDshort = GCPMD+KCPMD

KCPMDlong = [
KCPMDlong_Diamond,
KCPMDlong_Si
]

CPMDall = CPMDshort+KCPMDlong
KCPMDall = KCPMD+KCPMDlong

NECI = [
NECI_O3,
NECI_H2,
NECI_MC_H2O,
NECI_B_UHF,
NECI_HUB2x2n4,
NECI_HUB2x2tn4,
NECI_BOX_2eR10diag,
]

NECIlong = [
NECIlong_MC_O3,
NECIlong_Ne,
NECI_NN_STARDF_32BIT
]

NECIall = NECI+NECIlong

shortjobs = CPMDshort+NECI

longjobs = KCPMDlong+NECIlong

# alljobs is used to run the benchmarks.
# This allows specific jobs (e.g. for 32-bit platforms only) to not be included
# in a regular test.  Additional jobs can be specified via the command line
# options.
alljobs = CPMDall+NECIall

# Specify a default category.  Run if no jobs are provided via the command line.
defaultjobs=shortjobs



# Do not change: analyse the name space to get a list of all the jobtypes.
# This allows us to reference all the job categories without knowing 
# beforehand what they are (as in userconfig).
jobcategories={}
for catname,catdata in locals().items():
    if isinstance(catdata,list):
        if isinstance(catdata[0],dict) and 'type' in catdata[0]:
            # item is a job category list.
            jobcategories[catname]=catdata
